require 'spec_helper'

describe "Folders" do
  it "should have a default client" do
    sut = Grapefruit::Folder.new
    expect(sut.client).to be
  end
  it "should be able to take a custom client" do
    fake = FakeCMISClient.new
    sut = Grapefruit::Folder.new(fake)
    expect(sut.client).to eq(fake)
  end
  it "should have a title" do
    sut = Grapefruit::Folder.new(FakeCMISClient)
    sut.title = "Title"
    expect(sut.title).to eq("Title")
  end

  it "should have a cmis object id" do
    sut = Grapefruit::Folder.new(FakeCMISClient)
    sut.cmis_object_id = 123
    expect(sut.cmis_object_id).to eq(123)
  end

  context "Persisting Folders" do
    it "should be able to persist a folder using the client" do
      mock = double(Grapefruit::CmisClient, :create_folder => true)
      sut = Grapefruit::Folder.new(mock)
      mock.should_receive(:create_folder).with(sut)
      sut.save
    end
  end

  context "Viewing as XML" do
    it "should be able to represent itself as an CMIS XML document" do
      sut = Grapefruit::Folder.new(FakeCMISClient.new)
      sut.title = "Cats are Cool"

      xml_string = <<-eoxml
        <?xml version="1.0" encoding="utf-8"?>
        <entry xmlns="http://www.w3.org/2005/Atom"
        xmlns:cmisra="http://docs.oasis-open.org/ns/cmis/restatom/200908/"
        xmlns:cmis="http://docs.oasis-open.org/ns/cmis/core/200908/">
         <title>Cats are Cool</title>
         <cmisra:object>
         <cmis:properties>
         <cmis:propertyId propertyDefinitionId="cmis:objectTypeId">
            <cmis:value>cmis:folder</cmis:value>
          </cmis:propertyId>
         </cmis:properties>
         </cmisra:object>
        </entry>
      eoxml

      expect(sut.to_xml).to eq(xml_string)
    end
  end
end

